AppleDebugProvider class

Debug provider for Apple platforms.

No further configuration in your iOS code required. You simply need to copy/paste the debug token from the console when you run the app and add the token to your Firebase console.

If you set the debugToken here, it will be used when activating the provider.

See documentation: https://firebase.google.com/docs/app-check/ios/debug-provider

Inheritance

Constructors

AppleDebugProvider({String? debugToken})
Creates an Apple debug provider with an optional debug token.
const

Properties

debugToken String?
The debug token for this provider.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited