GoogleSignInAuthenticationEventSignOut class
A sign-out event, corresponding to a user having been signed out.
Implicit sign-outs (for example, due to server-side authentication revocation, or timeouts) are not guaranteed to send events.
- Inheritance
-
- Object
- GoogleSignInAuthenticationEvent
- GoogleSignInAuthenticationEventSignOut
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited