AppleDebugProvider constructor
const
AppleDebugProvider({
- String? debugToken,
Creates an Apple debug provider with an optional debug token.
The debugToken can be set here or passed separately to the activate method.
You have to re-run app after changing debug token.
Implementation
const AppleDebugProvider({this.debugToken}) : super('debug');